summaryrefslogtreecommitdiff
path: root/tests/frontend
diff options
context:
space:
mode:
authorJohn McLear <john@mclear.co.uk>2014-11-27 23:10:40 +0000
committerJohn McLear <john@mclear.co.uk>2014-11-27 23:10:40 +0000
commit47029f2e6bdc02f4d7b19cbb52ea2e7399edcb53 (patch)
tree3976af57c3e3f048a8baed82fa9784bca64500aa /tests/frontend
parent617514b335611b19730f03c9a352be1bbe701a59 (diff)
downloadetherpad-lite-47029f2e6bdc02f4d7b19cbb52ea2e7399edcb53.zip
diable caret tests for now
Diffstat (limited to 'tests/frontend')
-rw-r--r--tests/frontend/specs/caret.js13
1 files changed, 9 insertions, 4 deletions
diff --git a/tests/frontend/specs/caret.js b/tests/frontend/specs/caret.js
index a0cf0c3a..c1cdc724 100644
--- a/tests/frontend/specs/caret.js
+++ b/tests/frontend/specs/caret.js
@@ -1,6 +1,7 @@
describe("As the caret is moved is the UI properly updated?", function(){
var padName;
var numberOfRows = 50;
+/*
//create a new pad before each test run
beforeEach(function(cb){
@@ -8,10 +9,11 @@ describe("As the caret is moved is the UI properly updated?", function(){
this.timeout(60000);
});
- it("creates a pad", function(done) {
+ xit("creates a pad", function(done) {
padName = helper.newPad(done);
this.timeout(60000);
});
+*/
/* Tests to do
* Keystroke up (38), down (40), left (37), right (39) with and without special keys IE control / shift
@@ -26,10 +28,12 @@ describe("As the caret is moved is the UI properly updated?", function(){
* How do we keep the authors focus on a line if the lines above the author are modified? We should only redraw the user to a location if they are typing and make sure shift and arrow keys aren't redrawing the UI else highlight - copy/paste would get broken
* How can we simulate an edit event in the test framework?
*/
-
- // THIS DOESNT WORK AS IT DOESNT MOVE THE CURSOR!
+/*
+ // THIS DOESNT WORK IN CHROME AS IT DOESNT MOVE THE CURSOR!
it("down arrow", function(done){
var inner$ = helper.padInner$;
+ var chrome$ = helper.padChrome$;
+
var $newFirstTextElement = inner$("div").first();
$newFirstTextElement.focus();
keyEvent(inner$, 37, false, false); // arrow down
@@ -37,9 +41,10 @@ describe("As the caret is moved is the UI properly updated?", function(){
done();
});
-/*
+
it("Creates N lines", function(done){
var inner$ = helper.padInner$;
+console.log(inner$);
var chrome$ = helper.padChrome$;
var $newFirstTextElement = inner$("div").first();